@@ -6,10 +6,7 @@ use WWW::CurlOO ();
 use Exporter ();
 
 our @ISA = qw(Exporter);
-our @EXPORT_OK = (
-# @CURLOPT_INCLUDE@
-);
-
+our @EXPORT_OK = grep /^CURL/, keys %{WWW::CurlOO::Share::};
 our %EXPORT_TAGS = ( constants => \@EXPORT_OK );
 
 1;
